@@ -20,12 +20,11 @@
 """Check Command Module."""
 
 import os
+
 import click
 
-from molecule import logger
+from molecule import logger, util
 from molecule.command import base
-from molecule import util
-
 
 LOG = logger.get_logger(__name__)
 MOLECULE_PARALLEL = os.environ.get("MOLECULE_PARALLEL", False)
@@ -66,9 +65,9 @@ class Check(base.Base):
         Load an env file to read variables from when rendering
         molecule.yml.
 
-    .. program:: molecule --parallel check
+    .. program:: molecule check --parallel
 
-    .. option:: molecule --parallel check
+    .. option:: molecule check --parallel
 
        Run in parallelizable mode.
     """
