@@ -23,6 +23,8 @@ import abc
 import inspect
 import os
 
+import pkg_resources
+
 import molecule
 from molecule.status import Status
 
@@ -41,6 +43,8 @@ class Driver(object):
         """
         self._config = config
         self._path = os.path.abspath(os.path.dirname(inspect.getfile(self.__class__)))
+        self.module = self.__module__.split(".")[0]
+        self.version = pkg_resources.get_distribution(self.module).version
 
     @property  # type: ignore
     @abc.abstractmethod
@@ -50,7 +54,6 @@ class Driver(object):
 
         :returns: str
         """
-        pass
 
     @name.setter  # type: ignore
     @abc.abstractmethod
@@ -60,7 +63,6 @@ class Driver(object):
 
         :returns: None
         """
-        pass
 
     @property
     def testinfra_options(self):
@@ -82,7 +84,6 @@ class Driver(object):
 
         :returns: str
         """
-        pass
 
     @abc.abstractproperty
     def default_ssh_connection_options(self):  # pragma: no cover
@@ -91,7 +92,6 @@ class Driver(object):
 
         :returns: list
         """
-        pass
 
     @abc.abstractproperty
     def default_safe_files(self):  # pragma: no cover
@@ -100,7 +100,6 @@ class Driver(object):
 
         :returns: list
         """
-        pass
 
     @abc.abstractmethod
     def login_options(self, instance_name):  # pragma: no cover
@@ -110,7 +109,6 @@ class Driver(object):
         :param instance_name: A string containing the instance to login to.
         :returns: dict
         """
-        pass
 
     @abc.abstractmethod
     def ansible_connection_options(self, instance_name):  # pragma: no cover
@@ -121,7 +119,6 @@ class Driver(object):
         :param instance_name: A string containing the instance to login to.
         :returns: dict
         """
-        pass
 
     @abc.abstractmethod
     def sanity_checks(self):
@@ -136,7 +133,6 @@ class Driver(object):
 
         :returns: None
         """
-        pass
 
     @property
     def options(self):
@@ -251,6 +247,10 @@ class Driver(object):
         """Return detailed string representation of object."""
         return self.name
 
+    def __rich__(self):
+        """Return rich representation of object."""
+        return self.__str__()
+
     def template_dir(self):
 
         p = os.path.join(self._path, "cookiecutter")
@@ -274,7 +274,11 @@ class Driver(object):
         class, allowing driver writers to define playbooks without having
         to override this method.
         """
-        p = os.path.join(self._path, "playbooks", step + ".yml",)
+        p = os.path.join(
+            self._path,
+            "playbooks",
+            step + ".yml",
+        )
         if os.path.isfile(p):
             return p
 
@@ -291,4 +295,3 @@ class Driver(object):
         by molecule, regardless the scenario name.  Molecule will use metadata
         like labels or tags to annotate resources allocated by it.
         """
-        pass
