@@ -20,18 +20,17 @@
 #  DEALINGS IN THE SOFTWARE.
 
 import os
-import platform
 import shutil
 import subprocess
-from subprocess import PIPE, check_output
+from subprocess import PIPE
 
 import pexpect
 import pkg_resources
 import pytest
 import sh
-from packaging import version
 
 from molecule import logger, util
+from molecule.config import ansible_version
 from molecule.test.conftest import change_dir_to
 
 LOG = logger.get_logger(__name__)
@@ -44,8 +43,6 @@ MIN_PODMAN_VERSION = "1.5.1"
 
 @pytest.fixture(scope="session", autouse=True)
 def require_installed_package():
-    import pkg_resources
-
     try:
         pkg_resources.require("molecule")
     except pkg_resources.DistributionNotFound as e:
@@ -85,8 +82,6 @@ def with_scenario(request, scenario_to_test, driver_name, scenario_name, skip_te
 def skip_test(request, driver_name):
     msg_tmpl = "Skipped '{}' not supported"
     support_checks_map = {
-        "docker": supports_docker,
-        "podman": supports_podman,
         "delegated": lambda: True,
     }
     try:
@@ -139,7 +134,7 @@ def init_scenario(temp_dir, driver_name):
         molecule_directory = pytest.helpers.molecule_directory()
         scenario_directory = os.path.join(molecule_directory, "test-scenario")
 
-        options = {"role_name": "test-init"}
+        options = {"role-name": "test-init", "driver-name": driver_name}
         cmd = sh.molecule.bake("init", "scenario", "test-scenario", **options)
         pytest.helpers.run_command(cmd)
 
@@ -251,10 +246,6 @@ def get_docker_executable():
     return shutil.which("docker")
 
 
-def get_podman_executable():
-    return shutil.which("podman")
-
-
 def get_virtualbox_executable():
     return shutil.which("VBoxManage")
 
@@ -280,54 +271,6 @@ def supports_docker():
     return True
 
 
-@pytest.helpers.register
-@util.lru_cache()
-def supports_podman():
-    # Returns true if podman is supported and working
-    # Returns false if podman in not supported
-    # Calls pytest.fail if podman appears to be broken
-    if not min_ansible("2.8.6") or platform.system() == "Darwin":
-        LOG.warning("Podman not supported with current ansible/platform combination.")
-        return False
-
-    podman = get_podman_executable()
-    if not podman:
-        LOG.warning("Failed to locate podman executable.")
-        return False
-
-    result = subprocess.run([podman, "info"], stdout=PIPE, universal_newlines=True)
-    if result.returncode != 0:
-        LOG.error(
-            "Error %s returned from `podman info`: %s",
-            result.returncode,
-            result.stdout,
-        )
-        pytest.fail("Cannot run podman tests with a broken podman installation.")
-        return False
-
-    # checks for minimal version of podman
-    cmd = ["podman", "version", "-f", "{{.Version}}"]
-    podman_version = check_output(
-        cmd, stderr=subprocess.STDOUT, universal_newlines=True
-    )
-    if version.parse(podman_version) < version.parse(MIN_PODMAN_VERSION):
-        pytest.fail(
-            "Podman driver requires version >={}, and you have {}".format(
-                MIN_PODMAN_VERSION, podman_version
-            )
-        )
-
-    return True
-
-
-def min_ansible(version):
+def min_ansible(version: str) -> bool:
     """Ensure current Ansible is newer than a given a minimal one."""
-    try:
-        from ansible.release import __version__
-
-        return pkg_resources.parse_version(__version__) >= pkg_resources.parse_version(
-            version
-        )
-    except ImportError as exception:
-        LOG.error("Unable to parse Ansible version", exc_info=exception)
-        return False
+    return ansible_version() >= ansible_version(version)
