@@ -18,13 +18,9 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 
-import os
-
 import pytest
 import sh
 
-from molecule.scenario import ephemeral_directory
-
 
 @pytest.fixture
 def scenario_to_test(request):
@@ -48,9 +44,7 @@ def driver_name(request):
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
     [
-        ("driver/docker", "docker", "default"),
         ("driver/delegated", "delegated", "default"),
-        ("driver/podman", "podman", "default"),
     ],
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 )
@@ -64,9 +58,7 @@ def test_command_check(scenario_to_test, with_scenario, scenario_name):
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
     [
-        ("driver/docker", "docker", "default"),
         ("driver/delegated", "delegated", "default"),
-        ("driver/podman", "podman", "default"),
     ],
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 )
@@ -80,9 +72,7 @@ def test_command_cleanup(scenario_to_test, with_scenario, scenario_name):
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
     [
-        ("driver/docker", "docker", "default"),
         ("driver/delegated", "delegated", "default"),
-        ("driver/podman", "podman", "default"),
     ],
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 )
@@ -96,9 +86,7 @@ def test_command_converge(scenario_to_test, with_scenario, scenario_name):
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
     [
-        ("driver/docker", "docker", "default"),
         ("driver/delegated", "delegated", "default"),
-        ("driver/podman", "podman", "default"),
     ],
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 )
@@ -108,78 +96,30 @@ def test_command_create(scenario_to_test, with_scenario, scenario_name):
     pytest.helpers.run_command(cmd)
 
 
-@pytest.mark.skip(
-    reason="Disabled due to https://github.com/ansible/galaxy/issues/2030"
-)
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
     [
-        ("dependency", "docker", "ansible-galaxy"),
-        ("dependency", "podman", "ansible-galaxy"),
+        pytest.param("dependency", "delegated", "shell", id="shell"),
+        pytest.param("dependency", "delegated", "ansible-galaxy", id="galaxy"),
     ],
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 )
-def test_command_dependency_ansible_galaxy(
-    request, scenario_to_test, with_scenario, scenario_name
-):
+def test_command_dependency(request, scenario_to_test, with_scenario, scenario_name):
     options = {"scenario_name": scenario_name}
     cmd = sh.molecule.bake("dependency", **options)
-    pytest.helpers.run_command(cmd)
+    result = pytest.helpers.run_command(cmd, log=False)
+    assert result.exit_code == 0
 
-    dependency_role = os.path.join(
-        ephemeral_directory("molecule"),
-        "dependency",
-        "ansible-galaxy",
-        "roles",
-        "timezone",
-    )
-    assert os.path.isdir(dependency_role)
-
-
-@pytest.mark.parametrize(
-    "scenario_to_test, driver_name, scenario_name",
-    [("dependency", "docker", "gilt"), ("dependency", "podman", "gilt")],
-    indirect=["scenario_to_test", "driver_name", "scenario_name"],
-)
-def test_command_dependency_gilt(
-    request, scenario_to_test, with_scenario, scenario_name
-):
-    options = {"scenario_name": scenario_name}
-    cmd = sh.molecule.bake("dependency", **options)
-    pytest.helpers.run_command(cmd)
-
-    dependency_role = os.path.join(
-        ephemeral_directory("molecule"), "dependency", "gilt", "roles", "timezone"
-    )
-    assert os.path.isdir(dependency_role)
-
-
-@pytest.mark.parametrize(
-    "scenario_to_test, driver_name, scenario_name",
-    [("dependency", "docker", "shell"), ("dependency", "podman", "shell")],
-    indirect=["scenario_to_test", "driver_name", "scenario_name"],
-)
-def test_command_dependency_shell(
-    request, scenario_to_test, with_scenario, scenario_name
-):
-    options = {"scenario_name": scenario_name}
-    cmd = sh.molecule.bake("dependency", **options)
-    pytest.helpers.run_command(cmd)
-
-    dependency_role = os.path.join(
-        ephemeral_directory("molecule"), "dependency", "shell", "roles", "timezone"
-    )
-    assert os.path.isdir(dependency_role)
+    # Validate that depdendency worked by running converge, which make use
+    cmd = sh.molecule.bake("converge", **options)
+    result = pytest.helpers.run_command(cmd, log=False)
+    assert result.exit_code == 0
 
 
 @pytest.mark.extensive
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
-    [
-        ("driver/docker", "docker", "default"),
-        ("driver/delegated", "delegated", "default"),
-        ("driver/podman", "podman", "default"),
-    ],
+    [("driver/delegated", "delegated", "default")],
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 )
 def test_command_destroy(scenario_to_test, with_scenario, scenario_name):
@@ -192,9 +132,7 @@ def test_command_destroy(scenario_to_test, with_scenario, scenario_name):
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
     [
-        ("driver/docker", "docker", "default"),
         ("driver/delegated", "delegated", "default"),
-        ("driver/podman", "podman", "default"),
     ],
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 )
@@ -202,16 +140,12 @@ def test_command_idempotence(scenario_to_test, with_scenario, scenario_name):
     pytest.helpers.idempotence(scenario_name)
 
 
-@pytest.mark.parametrize(
-    "driver_name", [("docker"), ("podman")], indirect=["driver_name"]
-)
+@pytest.mark.parametrize("driver_name", [("delegated")], indirect=["driver_name"])
 def test_command_init_role(temp_dir, driver_name, skip_test):
     pytest.helpers.init_role(temp_dir, driver_name)
 
 
-@pytest.mark.parametrize(
-    "driver_name", [("docker"), ("podman")], indirect=["driver_name"]
-)
+@pytest.mark.parametrize("driver_name", [("delegated")], indirect=["driver_name"])
 def test_command_init_scenario(temp_dir, driver_name, skip_test):
     pytest.helpers.init_scenario(temp_dir, driver_name)
 
@@ -220,9 +154,7 @@ def test_command_init_scenario(temp_dir, driver_name, skip_test):
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
     [
-        ("driver/docker", "docker", "default"),
         ("driver/delegated", "delegated", "default"),
-        ("driver/podman", "podman", "default"),
     ],
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 )
@@ -235,71 +167,11 @@ def test_command_lint(scenario_to_test, with_scenario, scenario_name):
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, expected",
     [
-        (
-            "driver/docker",
-            "docker",
-            """
-Instance Name    Driver Name    Provisioner Name    Scenario Name    Created    Converged
-
----------------  -------------  ------------------  ---------------  ---------  -----------
-instance         docker         ansible             default
-instance-1       docker         ansible             multi-node
-instance-2       docker         ansible             multi-node
-""".strip(),
-        ),  # noqa
-        (
-            "driver/delegated",
-            "delegated",
-            """
-Instance Name    Driver Name    Provisioner Name    Scenario Name    Created    Converged
----------------  -------------  ------------------  ---------------  ---------  -----------
-instance         delegated      ansible             default
-""".strip(),
-        ),  # noqa
-        (
-            "driver/podman",
-            "podman",
-            """
-Instance Name    Driver Name    Provisioner Name    Scenario Name    Created    Converged
----------------  -------------  ------------------  ---------------  ---------  -----------
-instance         podman         ansible             default
-instance-1       podman         ansible             multi-node
-instance-2       podman         ansible             multi-node
-""".strip(),
-        ),  # noqa
-    ],
-    indirect=["scenario_to_test", "driver_name"],
-)
-def test_command_list(scenario_to_test, with_scenario, expected):
-    pytest.helpers.list(expected)
-
-
-@pytest.mark.parametrize(
-    "scenario_to_test, driver_name, expected",
-    [
-        (
-            "driver/docker",
-            "docker",
-            """
-instance    docker  ansible  default
-instance-1  docker  ansible  multi-node
-instance-2  docker  ansible  multi-node
-""".strip(),
-        ),
         (
             "driver/delegated",
             "delegated",
             """
 instance  delegated  ansible  default
-""".strip(),
-        ),
-        (
-            "driver/podman",
-            "podman",
-            """
-instance    podman  ansible  default
-instance-1  podman  ansible  multi-node
-instance-2  podman  ansible  multi-node
 """.strip(),
         ),
     ],
@@ -309,37 +181,27 @@ def test_command_list_with_format_plain(scenario_to_test, with_scenario, expecte
     pytest.helpers.list_with_format_plain(expected)
 
 
-@pytest.mark.parametrize(
-    "scenario_to_test, driver_name, login_args, scenario_name",
-    [
-        ("driver/docker", "docker", [["instance", ".*instance.*"]], "default"),
-        (
-            "driver/docker",
-            "docker",
-            [["instance-1", ".*instance-1.*"], ["instance-2", ".*instance-2.*"]],
-            "multi-node",
-        ),
-        ("driver/delegated", "delegated", [["instance", ".*instance.*"]], "default",),
-        (
-            "driver/podman",
-            "podman",
-            [["instance-1", ".*instance-1.*"], ["instance-2", ".*instance-2.*"]],
-            "multi-node",
-        ),
-    ],
-    indirect=["scenario_to_test", "driver_name", "scenario_name"],
-)
-def test_command_login(scenario_to_test, with_scenario, login_args, scenario_name):
-    pytest.helpers.login(login_args, scenario_name)
+# @pytest.mark.parametrize(
+#     "scenario_to_test, driver_name, login_args, scenario_name",
+#     [
+#         (
+#             "driver/delegated",
+#             "delegated",
+#             [["instance", ".*instance.*"]],
+#             "default",
+#         ),
+#     ],
+#     indirect=["scenario_to_test", "driver_name", "scenario_name"],
+# )
+# def test_command_login(scenario_to_test, with_scenario, login_args, scenario_name):
+#     pytest.helpers.login(login_args, scenario_name)
 
 
 @pytest.mark.extensive
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
     [
-        ("driver/docker", "docker", "default"),
         ("driver/delegated", "delegated", "default"),
-        ("driver/podman", "podman", "default"),
     ],
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 )
@@ -357,9 +219,7 @@ def test_command_prepare(scenario_to_test, with_scenario, scenario_name):
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
     [
-        ("driver/docker", "docker", "default"),
         ("driver/delegated", "delegated", "default"),
-        ("driver/podman", "podman", "default"),
     ],
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 )
@@ -373,9 +233,7 @@ def test_command_side_effect(scenario_to_test, with_scenario, scenario_name):
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
     [
-        ("driver/docker", "docker", "default"),
         ("driver/delegated", "delegated", "default"),
-        ("driver/podman", "podman", "default"),
     ],
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 )
@@ -388,10 +246,7 @@ def test_command_syntax(scenario_to_test, with_scenario, scenario_name):
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
     [
-        ("driver/docker", "docker", "default"),
-        ("driver/docker", "docker", "multi-node"),
         ("driver/delegated", "delegated", "default"),
-        ("driver/podman", "podman", "default"),
     ],
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 )
@@ -403,9 +258,7 @@ def test_command_test(scenario_to_test, with_scenario, scenario_name, driver_nam
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
     [
-        ("driver/docker", "docker", "default"),
         ("driver/delegated", "delegated", "default"),
-        ("driver/podman", "podman", "default"),
     ],
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 )
